@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2008 Nicolas Burrus
+# Copyright (C) 2005, 2008, 2009 Nicolas Burrus
 # This file is part of Tidydoc.
 #
 # Tidydoc is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from glob import glob
-import popen2
+import subprocess
 import os.path
 import re
 import os
@@ -54,14 +54,18 @@ def get_site_path(input_path):
   return os.path.join(config['site_root'], rel_path(input_path))
 
 def exec_commands(cmds):
-  subprocess = popen2.Popen4 ("sh")
-  subprocess.tochild.write(cmds)
-  subprocess.tochild.write("exit\n")
-  subprocess.tochild.flush()
-  lines = subprocess.fromchild.readlines()
-  subprocess.tochild.close()
-  subprocess.fromchild.close()
-  status = subprocess.wait()
+  p = subprocess.Popen(cmds, shell=True,
+                       stdout=subprocess.PIPE, 
+                       stderr=subprocess.STDOUT, 
+                       close_fds=True)
+  if not p:
+    raise Exception("Could not open Pipe!")
+  child_stdout_and_stderr = p.stdout
+  lines = child_stdout_and_stderr.readlines()
+  status = p.wait()
+  if status != 0:
+    msg = "Could not run `%s': %s" % (cmds,"\n".join(lines))
+    raise Exception(msg)
   return status, lines
 
 def guess_desc_from_pdf(desc, doc_path):
@@ -83,18 +87,20 @@ def guess_desc_from_pdf(desc, doc_path):
   if status == 0 and len(output) > 0:
     desc['pages'] = output[0].strip("\n")
 
-  cmd = "pdfinfo \"%s\" 2> /dev/null | grep CreationDate: | sed 's/CreationDate:[ \t]\+//'\n" \
-        % doc_path
+  cmd = "pdfinfo \"%s\" 2> /dev/null | grep CreationDate:" % doc_path
   (status, output) = exec_commands(cmd)
   if status == 0 and len(output) > 0:
-    desc['date'] = output[0].strip("\n")
+    m = re.match("^.*(\d{4})$", output[0].rstrip())
+    if m:
+      desc['date'] = m.group(1)
   return desc
 
 def guess_desc_from_doc(doc_path):
   desc = { 'author' : "",
            'date'   : "",
            'pages'  : "",
-           'title'  : ""}
+           'title'  : "",
+           'conf'   : ""}
   if re.match(".*\.pdf$", doc_path):
     return guess_desc_from_pdf(desc, doc_path)
   return desc
