@@ -35,8 +35,7 @@ fields = [ 'author',
            'title',
            'type',
            'url',
-           'bibtex_type',
-           'bibtex_fields'
+           'bibtex',
            ]
 
 def parse(fname):  
