@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2005 Nicolas Burrus
+# Copyright (C) 2005, 2006, 2008, 2009 Nicolas Burrus
 # This file is part of Tidydoc.
 #
 # Tidydoc is free software; you can redistribute it and/or modify
@@ -23,6 +23,8 @@ from td_tools import *
 import td_config
 import td_xml
 import td_doctree
+import td_bibtex
+import td_debug
 from td_config import config
 import ac_config
 
@@ -45,6 +47,7 @@ def generate_document_index(doctree):
   
   for doc in doctree.docs:
     subs = {
+      '%%FIRST_AUTHOR%%' : doc.content['author'][0],
       '%%AUTHORS%%' : ", ".join(doc.content['author']),
       '%%LINK%%' : '#' + doc.content['title'][0],
       '%%NAME%%' : doc.content['title'][0]
@@ -52,23 +55,60 @@ def generate_document_index(doctree):
     html_output += replace_in_template(link_tpl, subs)
   return html_output
 
-def generate_document_list(doctree):
+def shorten_string(m):
+  s = m.group(2)
+  if (len(s) > 48):
+    s = s[0:23] + "..." + s[len(s)-1-23:len(s)]
+  return m.group(1) + s + m.group(3)
+
+def generate_html_code(doc, dirpath):
   document_tpl = os.path.join(config['templates_path'], 'html/document.tpl')
+  short_filename = re.sub(r'(.*\.)(.*)(\.\w+)$', 
+                          shorten_string,
+                          doc.content['file'][0])
+  subs = {
+        '%%ANCHOR%%'   : doc.content['title'][0],
+        '%%AUTHORS%%'  : "<br>".join(doc.content['author']),
+        '%%FIRST_AUTHOR%%' : doc.content['author'][0],
+        '%%CONF%%' : doc.content['conf'][0],
+        '%%DOC_ID%%' : doc.content['file'][0],
+        '%%DATE%%'     : doc.content['date'][0],
+        '%%LANGUAGE%%' : doc.content['language'][0],
+        '%%DOCPATH%%'  : dirpath + '/' + doc.content['file'][0],
+        '%%LINK%%'     : config['site_root'] + '/' + dirpath + '/' + doc.content['file'][0],
+        '%%LINK_NAME%%' : short_filename,
+        '%%SUMMARY%%'  : re.sub("\n", "<br>\n", doc.content['summary'][0]),
+        '%%COMMENT%%'  : doc.content['comment'][0],
+        '%%URL%%'      : doc.content['url'][0],
+        '%%TITLE%%'    : doc.content['title'][0],
+        '%%NBPAGES%%'  : doc.content['nbpages'][0],
+        '%%BIBTEX%%'   : td_bibtex.generate_bibtex_entry(doc),
+        }
+  doc_html = replace_in_template(document_tpl, subs)
+  return doc_html
+
+def generate_document_list(doctree):
   html_output = ""
-  
+
+  dirpath = os.path.abspath(doctree.path)
+  dirpath = dirpath.replace(os.path.abspath(config['input_path']), "").lstrip('/')
+ 
+  current_id = 0
   for doc in doctree.docs:
-    subs = {
-      '%%ANCHOR%%'   : doc.content['title'][0],
-      '%%AUTHORS%%'  : "<br>".join(doc.content['author']),
-      '%%DATE%%'     : doc.content['date'][0],
-      '%%LANGUAGE%%' : doc.content['language'][0],
-      '%%LINK%%'     : doc.content['file'][0],
-      '%%SUMMARY%%'  : re.sub("\n", "<br>\n", doc.content['summary'][0]),
-      '%%URL%%'      : doc.content['url'][0],
-      '%%TITLE%%'    : doc.content['title'][0],
-      '%%NBPAGES%%'  : doc.content['nbpages'][0],
-      }
-    html_output += replace_in_template(document_tpl, subs)
+    doc_html = ""
+    cache_file = config['input_path'] + '/' + dirpath + '/' + doc.content['file'][0] + ".html"
+    xml_file = config['input_path'] + '/' + dirpath + '/' + doc.content['file'][0] + ".xml"
+    if os.path.exists(cache_file) \
+       and os.path.exists(xml_file) \
+       and is_more_recent(cache_file, xml_file):
+      doc_html = open(cache_file, "r").read().decode("utf_8")
+    else:  
+      doc_html = generate_html_code(doc, dirpath)
+      # Cache
+      f = open(cache_file, "w")
+      f.write(doc_html.encode("utf_8"))
+      f.close()
+    html_output += doc_html
   return html_output
 
 def generate_html_file(doctree, fname):
@@ -95,8 +135,9 @@ def generate_html_file(doctree, fname):
     os.makedirs(os.path.dirname(output_file))
   except:
     pass
+
   f = open(output_file, "w")
-  f.write(html_content.encode("latin_1"))
+  f.write(html_content.encode("utf_8"))
   f.close()
 
 def generate_child_node(doctree):
@@ -162,10 +203,9 @@ def generate_treeview(doctree):
   
   f = open(os.path.join(treeview_path, 'docNodes.js'), "w")
   subs = { '%%TREE_CONTENT%%' : js }
-  f.write(replace_in_template(treeview_tpl, subs).encode("latin_1"))
+  f.write(replace_in_template(treeview_tpl, subs).encode("utf_8"))
   f.close()
 
 def generate(doctree):
   generate_html(doctree)
   generate_treeview(doctree)
-
